# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [0.2.10](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.10) - 2025-12-03

<small>[Compare with 0.2.9](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.9...0.2.10)</small>

### Bug Fixes

- avoid loading tracts if images exist ([caced32](https://github.com/mcw-meier-lab/pyTractoViz/commit/caced32fac302f9b6abb276d159d9d1cb46fc9f7) by Lezlie Espana).

## [0.2.9](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.9) - 2025-12-03

<small>[Compare with 0.2.8](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.8...0.2.9)</small>

### Bug Fixes

- more memory handling ([5ec2e2c](https://github.com/mcw-meier-lab/pyTractoViz/commit/5ec2e2c31829cc5aed3da7b13bcb40f123c12f9f) by Lezlie Espana).

## [0.2.8](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.8) - 2025-12-03

<small>[Compare with 0.2.7](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.7...0.2.8)</small>

### Bug Fixes

- multiprocessing ([6123ddb](https://github.com/mcw-meier-lab/pyTractoViz/commit/6123ddbb8597aceacb9b6a8acdcf2e6fd844517e) by Lezlie Espana).

## [0.2.7](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.7) - 2025-12-03

<small>[Compare with 0.2.6](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.6...0.2.7)</small>

### Bug Fixes

- more broken process pool handling ([a3774b6](https://github.com/mcw-meier-lab/pyTractoViz/commit/a3774b6899aa7d2a70407eeb0c7e4e1cda31f345) by Lezlie Espana).

## [0.2.6](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.6) - 2025-12-03

<small>[Compare with 0.2.5](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.5...0.2.6)</small>

### Bug Fixes

- add support for headless envs ([f7f8341](https://github.com/mcw-meier-lab/pyTractoViz/commit/f7f8341002009adc4157b4dcb2134850711802e2) by Lezlie Espana).

## [0.2.5](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.5) - 2025-12-02

<small>[Compare with 0.2.4](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.4...0.2.5)</small>

### Bug Fixes

- broken process pool ([fc84864](https://github.com/mcw-meier-lab/pyTractoViz/commit/fc84864badd086bce847f4cfa55ee6249172848f) by Lezlie Espana).

## [0.2.4](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.4) - 2025-12-02

<small>[Compare with 0.2.3](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.3...0.2.4)</small>

### Bug Fixes

- broken process pool error ([f877281](https://github.com/mcw-meier-lab/pyTractoViz/commit/f87728192d33cd1c5af805c4c7f342ef483c4ffd) by Lezlie Espana).

## [0.2.3](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.3) - 2025-12-02

<small>[Compare with 0.2.2](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.2...0.2.3)</small>

### Bug Fixes

- handling of reference images ([72fa597](https://github.com/mcw-meier-lab/pyTractoViz/commit/72fa597f63b36bf8dc5779501175d0bc4d5eb59e) by Lezlie Espana).

### Code Refactoring

- style, formatting to match changes ([436c0a1](https://github.com/mcw-meier-lab/pyTractoViz/commit/436c0a118c1c6ffb919eb0910beb40ab57a535fe) by Lezlie Espana).

## [0.2.2](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.2) - 2025-11-25

<small>[Compare with 0.2.1](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.1...0.2.2)</small>

## [0.2.1](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.1) - 2025-11-25

<small>[Compare with 0.2.0](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.2.0...0.2.1)</small>

## [0.2.0](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.2.0) - 2025-11-24

<small>[Compare with 0.1.0](https://github.com/mcw-meier-lab/pyTractoViz/compare/0.1.0...0.2.0)</small>

### Features

- add basic features ([fb9383e](https://github.com/mcw-meier-lab/pyTractoViz/commit/fb9383e832c910a0d7220d696b75798971e34866) by Lezlie Espana).

## [0.1.0](https://github.com/mcw-meier-lab/pyTractoViz/releases/tag/0.1.0) - 2025-11-11

<small>[Compare with first commit](https://github.com/mcw-meier-lab/pyTractoViz/compare/d737b5cd0c2e6bf53bccb92e2ec871dd5918332e...0.1.0)</small>

### Features

- Initial project commit ([d737b5c](https://github.com/mcw-meier-lab/pyTractoViz/commit/d737b5cd0c2e6bf53bccb92e2ec871dd5918332e) by Lezlie Espana).
